@@ -36,7 +36,6 @@
 #include "yelp-marshal.h"
 #include "yelp-error.h"
 #include "yelp-uri.h"
-#include "yelp-reader.h"
 #include "yelp-html.h"
 
 #define d(x)
@@ -46,7 +45,6 @@ struct _YelpHtmlPriv {
 
         HtmlDocument *doc;
 	YelpURI      *base_uri;
-	YelpReader   *reader;
 };
 
 
@@ -171,7 +169,6 @@ html_url_requested_cb (HtmlDocument *doc,
 	gchar             buffer[BUFFER_SIZE];
 	GnomeVFSFileSize  read_len;
 	gchar            *absolute_url;
-	gchar            *str_uri;
 	
         html = YELP_HTML (data);
 	priv = html->priv;
@@ -180,10 +177,7 @@ html_url_requested_cb (HtmlDocument *doc,
 
 	d(g_print ("URL REQUESTED: %s\n", url));
 
-	str_uri = yelp_uri_to_string (priv->base_uri);
-	absolute_url = yelp_util_resolve_relative_url (str_uri, url);
-	g_free (str_uri);
-	
+	absolute_url = yelp_util_resolve_relative_url (yelp_uri_get_path (priv->base_uri), url);
 	
 	result = gnome_vfs_open (&handle, absolute_url, GNOME_VFS_OPEN_READ);
 
@@ -273,7 +267,7 @@ yelp_html_new (void)
  	yelp_html_clear (html);
 	
  	{
- 		gchar *text = "<html><body bgcolor=\"white\"></body></html>";
+ 		gchar *text = "<html><body></body></html>";
 
  		yelp_html_write (html, text, -1);
  	}
