@@ -239,25 +239,29 @@ reader_convert_start (ReaderThreadData *th_data)
 
 	switch (yelp_uri_get_type (uri)) {
 	case YELP_URI_TYPE_MAN:
-		command_line = g_strdup_printf ("gnome2-man2html %s",
+		command_line = g_strdup_printf ("%s %s",
+						LIBGNOME_MAN2HTML,
 						yelp_uri_get_path (uri));
 		break;
 	case YELP_URI_TYPE_INFO:
 		if (yelp_uri_get_section (uri)) {
 			command_line = 
-				g_strdup_printf ("gnome2-info2html %s?%s",
+				g_strdup_printf ("%s %s?%s",
+						 LIBGNOME_INFO2HTML,
 						 yelp_uri_get_path (uri),
 						 yelp_uri_get_section (uri));
 		} else { 
 			command_line = 
-				g_strdup_printf ("gnome2-info2html %s",
+				g_strdup_printf ("%s %s",
+						 LIBGNOME_INFO2HTML,
 						 yelp_uri_get_path (uri));
 		}
 		
 		break;
 	case YELP_URI_TYPE_DOCBOOK_XML:
 	case YELP_URI_TYPE_DOCBOOK_SGML:
-		command_line = g_strdup_printf ("yelp-db2html %s",
+		command_line = g_strdup_printf ("%s/yelp-db2html %s",
+						SERVERDIR,
 						yelp_uri_get_path (uri));
 		break;
 	default:
@@ -272,7 +276,7 @@ reader_convert_start (ReaderThreadData *th_data)
 
 	q_data = reader_q_data_new (reader, priv->stamp, 
 				    READER_QUEUE_TYPE_DATA);
-	
+
 	g_spawn_command_line_sync (command_line,
 				   &q_data->data,
 				   NULL,
@@ -367,7 +371,7 @@ reader_file_start (ReaderThreadData *th_data)
 	STAMP_MUTEX_UNLOCK;
 
 	result = gnome_vfs_open (&handle, 
-				 yelp_uri_get_path (uri),
+				 yelp_uri_get_path (uri), 
 				 GNOME_VFS_OPEN_READ);
 	
 	if (result != GNOME_VFS_OK) {
@@ -400,7 +404,7 @@ reader_file_start (ReaderThreadData *th_data)
 		
 		STAMP_MUTEX_UNLOCK;
 	}
-	
+
 	q_data = reader_q_data_new (reader, stamp, READER_QUEUE_TYPE_FINISHED);
 
 	g_async_queue_push (priv->thread_queue, q_data);
@@ -792,9 +796,11 @@ yelp_reader_start (YelpReader *reader, YelpURI *uri)
 	
 	g_timeout_add (100, (GSourceFunc) reader_idle_check_queue, th_data);
 
-	g_thread_create ((GThreadFunc) reader_start, th_data,
-			 TRUE, 
-			 NULL /* FIXME: check for errors */);
+	g_thread_create_full ((GThreadFunc) reader_start, th_data,
+			      2 * BUFFER_SIZE,
+			      TRUE,
+			      FALSE, G_THREAD_PRIORITY_NORMAL,
+			      NULL /* FIXME: check for errors */);
 	return FALSE;
 }
 
