@@ -30,9 +30,12 @@
 #include <gconf/gconf-client.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomeui/gnome-about.h>
+#include <libgnomeui/gnome-stock-icons.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-url.h>
+#include <libgnome/gnome-program.h>
 #include <string.h>
+#include "yelp-error.h"
 #include "yelp-html.h"
 #include "yelp-util.h"
 #include "yelp-section.h"
@@ -46,73 +49,78 @@
 
 typedef enum {
 	YELP_WINDOW_ACTION_BACK = 1,
-	YELP_WINDOW_ACTION_FORWARD,
+	YELP_WINDOW_ACTION_FORWARD
 } YelpHistoryAction;
 
 static GConfEnumStringPair toolbar_styles[] = {
         { GTK_TOOLBAR_TEXT, "text" },
         { GTK_TOOLBAR_ICONS, "icons" },
-        { GTK_TOOLBAR_BOTH, "both" }
+        { GTK_TOOLBAR_BOTH, "both" },
+	{ GTK_TOOLBAR_BOTH_HORIZ, "both_horiz" }
 };
 
-static void        yw_init		       (YelpWindow          *window);
-static void        yw_class_init	       (YelpWindowClass     *klass);
+static void        window_init		          (YelpWindow        *window);
+static void        window_class_init	          (YelpWindowClass   *klass);
 
-static void        yw_populate                 (YelpWindow          *window);
+static void        window_populate                (YelpWindow        *window);
 
-static gboolean    yw_handle_uri               (YelpWindow          *window,
-						YelpURI             *uri);
-static void        yw_uri_selected_cb          (gpointer             view,
-						YelpURI             *uri,
-						gboolean             handled,
-						YelpWindow          *window);
-static void        yw_toggle_history_back      (YelpHistory         *history,
-						gboolean             sensitive,
-						YelpWindow          *window);
+static gboolean    window_handle_uri              (YelpWindow        *window,
+						   YelpURI           *uri);
+static void        window_uri_selected_cb         (gpointer           view,
+						   YelpURI           *uri,
+						   gboolean           handled,
+						   YelpWindow        *window);
+static void        window_title_changed_cb        (gpointer           view,
+						   const gchar       *title,
+						   YelpWindow        *window);
+static void        window_toggle_history_back     (YelpHistory       *history,
+						   gboolean           sensitive,
+						   YelpWindow        *window);
+ 
+static void        window_toggle_history_forward  (YelpHistory       *history,
+						   gboolean           sensitive,
+						   YelpWindow        *window);
 
-static void        yw_toggle_history_forward   (YelpHistory         *history,
-						gboolean             sensitive,
-						YelpWindow          *window);
+static void        window_history_action          (YelpWindow        *window,
+						   YelpHistoryAction  action);
+static void        window_back_button_clicked     (GtkWidget         *button,
+						   YelpWindow        *window);
+static void        window_forward_button_clicked  (GtkWidget         *button,
+						   YelpWindow        *window);
+static void        window_home_button_clicked     (GtkWidget         *button,
+						   YelpWindow        *window);
+static void        window_index_button_clicked    (GtkWidget         *button,
+						   YelpWindow        *window);
+static void        window_new_window_cb           (gpointer           data,
+						   guint              section,
+						   GtkWidget         *widget);
+static void        window_close_window_cb         (gpointer           data,
+						   guint              section,
+						   GtkWidget         *widget);
+static void        window_history_go_cb           (gpointer           data,
+						   guint              section,
+						   GtkWidget         *widget);
+static void        window_go_home_cb              (gpointer           data,
+						   guint              section,
+						   GtkWidget         *widget);
+static void        window_go_index_cb             (gpointer           data,
+						   guint              section,
+						   GtkWidget         *widget);
+static void        window_about_cb                (gpointer           data,
+						   guint              section,
+						   GtkWidget         *widget);
+static GtkWidget * window_create_toolbar          (YelpWindow        *window);
+
+static GdkPixbuf * window_load_icon               (void);
+
+static void        
+window_toolbar_style_changed_cb                   (GConfClient      *client,
+						   guint             cnxn_id,
+						   GConfEntry       *entry,
+						   gpointer          data);
 
-static void        yw_history_action           (YelpWindow          *window,
-						YelpHistoryAction    action);
-static void        yw_back_button_clicked      (GtkWidget           *button,
-						YelpWindow          *window);
-static void        yw_forward_button_clicked   (GtkWidget           *button,
-						YelpWindow          *window);
-static void        yw_home_button_clicked      (GtkWidget           *button,
-						YelpWindow          *window);
-static void        yw_index_button_clicked     (GtkWidget           *button,
-						YelpWindow          *window);
-static void        yw_new_window_cb            (gpointer             data,
-						guint                section,
-						GtkWidget           *widget);
-static void        yw_close_window_cb          (gpointer             data,
-						guint                section,
-						GtkWidget           *widget);
-static void        yw_history_go_cb            (gpointer             data,
-						guint                section,
-						GtkWidget           *widget);
-static void        yw_go_home_cb               (gpointer             data,
-						guint                section,
-						GtkWidget           *widget);
-static void        yw_go_index_cb              (gpointer             data,
-						guint                section,
-						GtkWidget           *widget);
-static void        yw_about_cb                 (gpointer             data,
-						guint                section,
-						GtkWidget           *widget);
-static GtkWidget * yw_create_toolbar           (YelpWindow          *window);
 
-static void        yw_toolbar_style_changed_cb (GConfClient         *client,
-						guint                cnxn_id,
-						GConfEntry          *entry,
-						gpointer             data);
 
-#if 0
-static void        yw_remove_notify_cb          (GtkObject          *obj, 
-						 gpointer            data);
-#endif
 
 enum {
 	PAGE_TOC_VIEW,
@@ -133,7 +141,7 @@ struct _YelpWindowPriv {
 
 	GtkWidget      *notebook;
 
-	GtkWidget      *toc_view;
+	YelpViewTOC    *toc_view;
 	GtkWidget      *content_view;
 	GtkWidget      *index_view;
 	
@@ -149,16 +157,16 @@ struct _YelpWindowPriv {
 
 static GtkItemFactoryEntry menu_items[] = {
 	{N_("/_File"),              NULL,         0,                  0,                           "<Branch>"},
-	{N_("/File/_New window"),   NULL,         yw_new_window_cb,   0,                           "<StockItem>", GTK_STOCK_NEW     },
-	{N_("/File/_Close window"), NULL,         yw_close_window_cb, 0,                           "<StockItem>", GTK_STOCK_CLOSE   },
-/*	{N_("/File/_Quit"),         NULL,         yw_exit_cb,         0,                           "<StockItem>", GTK_STOCK_QUIT    }, */
+	{N_("/File/_New window"),   NULL,         window_new_window_cb,   0,                           "<StockItem>", GTK_STOCK_NEW     },
+	{N_("/File/_Close window"), NULL,         window_close_window_cb, 0,                           "<StockItem>", GTK_STOCK_CLOSE   },
+/*	{N_("/File/_Quit"),         NULL,         window_exit_cb,         0,                           "<StockItem>", GTK_STOCK_QUIT    }, */
 	{N_("/_Go"),                NULL,         0,                  0,                           "<Branch>"},
-	{N_("/Go/_Back"),           NULL,         yw_history_go_cb,   YELP_WINDOW_ACTION_BACK,     "<StockItem>", GTK_STOCK_GO_BACK    },
-	{N_("/Go/_Forward"),        NULL,         yw_history_go_cb,   YELP_WINDOW_ACTION_FORWARD,  "<StockItem>", GTK_STOCK_GO_FORWARD },
-	{N_("/Go/_Home"),           NULL,         yw_go_home_cb,      0,                           "<StockItem>", GTK_STOCK_HOME },
-	{N_("/Go/_Index"),          NULL,         yw_go_index_cb,     0,                           "<StockItem>", GTK_STOCK_INDEX },
+	{N_("/Go/_Back"),           NULL,         window_history_go_cb,   YELP_WINDOW_ACTION_BACK,     "<StockItem>", GTK_STOCK_GO_BACK    },
+	{N_("/Go/_Forward"),        NULL,         window_history_go_cb,   YELP_WINDOW_ACTION_FORWARD,  "<StockItem>", GTK_STOCK_GO_FORWARD },
+	{N_("/Go/_Home"),           NULL,         window_go_home_cb,      0,                           "<StockItem>", GTK_STOCK_HOME },
+	{N_("/Go/_Index"),          NULL,         window_go_index_cb,     0,                           "<StockItem>", GTK_STOCK_INDEX },
 	{N_("/_Help"),              NULL,         0,                  0,                           "<Branch>"},
-	{N_("/Help/_About"),        NULL,         yw_about_cb,        0,                           NULL },
+	{N_("/Help/_About"),        NULL,         window_about_cb,        0,                           "<StockItem>", GNOME_STOCK_ABOUT },
 };
 
 GType
@@ -172,12 +180,12 @@ yelp_window_get_type (void)
                                 sizeof (YelpWindowClass),
                                 NULL,
                                 NULL,
-                                (GClassInitFunc) yw_class_init,
+                                (GClassInitFunc) window_class_init,
                                 NULL,
                                 NULL,
                                 sizeof (YelpWindow),
                                 0,
-                                (GInstanceInitFunc) yw_init,
+                                (GInstanceInitFunc) window_init,
                         };
                 
                 window_type = g_type_register_static (GTK_TYPE_WINDOW,
@@ -189,33 +197,29 @@ yelp_window_get_type (void)
 }
 
 static void
-yw_init (YelpWindow *window)
+window_init (YelpWindow *window)
 {
         YelpWindowPriv *priv;
-	YelpURI        *uri;
+/* 	YelpURI        *uri; */
 	
         priv = g_new0 (YelpWindowPriv, 1);
         window->priv = priv;
         
-	priv->toc_view    = NULL;
+	priv->toc_view     = NULL;
 	priv->content_view = NULL;
 	priv->index_view   = NULL;
 	priv->view_current = NULL;
 	
 	priv->history = yelp_history_new ();
 
-	uri = yelp_uri_new ("toc:");
-	yelp_history_goto (priv->history, uri);
-	yelp_uri_unref (uri);
-
 	g_signal_connect (priv->history, 
 			  "back_exists_changed",
-			  G_CALLBACK (yw_toggle_history_back),
+			  G_CALLBACK (window_toggle_history_back),
 			  window);
 
 	g_signal_connect (priv->history, 
 			  "forward_exists_changed",
-			  G_CALLBACK (yw_toggle_history_forward),
+			  G_CALLBACK (window_toggle_history_forward),
 			  window);
 
 	gtk_window_set_default_size (GTK_WINDOW (window), 600, 420);
@@ -224,7 +228,7 @@ yw_init (YelpWindow *window)
 }
 
 static void
-yw_class_init (YelpWindowClass *klass)
+window_class_init (YelpWindowClass *klass)
 {
 	signals[NEW_WINDOW_REQUESTED] =
 		g_signal_new ("new_window_requested",
@@ -238,7 +242,7 @@ yw_class_init (YelpWindowClass *klass)
 }
 
 static void
-yw_populate (YelpWindow *window)
+window_populate (YelpWindow *window)
 {
         YelpWindowPriv *priv;
 	GtkWidget      *toolbar;
@@ -255,7 +259,7 @@ yw_populate (YelpWindow *window)
 
 	accel_group  = gtk_accel_group_new ();
 	priv->item_factory = gtk_item_factory_new (GTK_TYPE_MENU_BAR, 
-					     "<main>", accel_group);
+						   "<main>", accel_group);
 
 	gtk_item_factory_set_translate_func (priv->item_factory, 
 					     (GtkTranslateFunc) gettext,
@@ -281,7 +285,7 @@ yw_populate (YelpWindow *window)
 							 "<main>"),
 			    FALSE, FALSE, 0);
 
-	toolbar         = yw_create_toolbar (window);
+	toolbar         = window_create_toolbar (window);
 
 	priv->notebook  = gtk_notebook_new ();
 
@@ -294,7 +298,8 @@ yw_populate (YelpWindow *window)
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
 
-	gtk_container_add (GTK_CONTAINER (sw), priv->toc_view);
+	gtk_container_add (GTK_CONTAINER (sw), 
+			   yelp_view_toc_get_widget (priv->toc_view));
 
 	gtk_notebook_insert_page (GTK_NOTEBOOK (priv->notebook),
 				  sw, NULL, PAGE_TOC_VIEW);
@@ -315,7 +320,7 @@ yw_populate (YelpWindow *window)
 }
 
 static gboolean
-yw_handle_uri (YelpWindow *window, YelpURI *uri)
+window_handle_uri (YelpWindow *window, YelpURI *uri)
 {
 	YelpWindowPriv *priv;
 	GError         *error = NULL;
@@ -325,9 +330,16 @@ yw_handle_uri (YelpWindow *window, YelpURI *uri)
 
 	d(g_print ("Handling URL: %s\n", yelp_uri_to_string (uri)));
 
-/*  	yelp_view_content_stop (YELP_VIEW_CONTENT (priv->content_view)); */
-
-	if (yelp_uri_get_type (uri) == YELP_URI_TYPE_TOC) {
+	if (!yelp_uri_exists (uri)) {
+		gchar *str_uri = yelp_uri_to_string (uri);
+		
+		g_set_error (&error,
+			     YELP_ERROR,
+			     YELP_ERROR_URI_NOT_EXIST,
+			     _("The document '%s' does not exist"), str_uri);
+		g_free (str_uri);
+	}
+	else if (yelp_uri_get_type (uri) == YELP_URI_TYPE_TOC) {
 		d(g_print ("[TOC]\n"));
 		
 		yelp_view_toc_open_uri (YELP_VIEW_TOC (priv->toc_view), uri);
@@ -335,10 +347,14 @@ yw_handle_uri (YelpWindow *window, YelpURI *uri)
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook),
 					       PAGE_TOC_VIEW);
 		handled = TRUE;
-	} 
+	}
 	else if (yelp_uri_get_type (uri) == YELP_URI_TYPE_INDEX) {
+		d(g_print ("[INDEX]\n"));
 		gtk_notebook_set_current_page (GTK_NOTEBOOK (priv->notebook),
 					       PAGE_INDEX_VIEW);
+		yelp_view_index_show_uri (YELP_VIEW_INDEX (priv->index_view),
+					  uri, 
+					  &error);
 		handled = TRUE;
 	}
 	else if (yelp_uri_get_type (uri) == YELP_URI_TYPE_MAN ||
@@ -375,10 +391,10 @@ yw_handle_uri (YelpWindow *window, YelpURI *uri)
 }
 
 static void
-yw_uri_selected_cb (gpointer    view, 
-		    YelpURI    *uri, 
-		    gboolean    handled,
-		    YelpWindow *window)
+window_uri_selected_cb (gpointer    view, 
+			YelpURI    *uri, 
+			gboolean    handled,
+			YelpWindow *window)
 {
 	YelpWindowPriv *priv;
 
@@ -394,7 +410,7 @@ yw_uri_selected_cb (gpointer    view,
 	if (handled) {
 		yelp_history_goto (priv->history, uri);
 	} else {
-		if (yw_handle_uri (window, uri)) {
+		if (window_handle_uri (window, uri)) {
 			yelp_history_goto (priv->history, uri);
 		}
 	}
@@ -403,9 +419,24 @@ yw_uri_selected_cb (gpointer    view,
 }
 
 static void
-yw_toggle_history_back (YelpHistory *history,
-			gboolean     sensitive,
-			YelpWindow  *window)
+window_title_changed_cb (gpointer view, const gchar *title, YelpWindow *window)
+{
+	gchar *new_title;
+	
+	g_return_if_fail (title != NULL);
+	g_return_if_fail (YELP_IS_WINDOW (window));
+	
+	new_title = g_strconcat (_("Help Browser"), ":", title, NULL);
+
+	gtk_window_set_title (GTK_WINDOW (window), new_title);
+
+	g_free (new_title);
+}
+
+static void
+window_toggle_history_back (YelpHistory *history,
+			    gboolean     sensitive,
+			    YelpWindow  *window)
 {
 	YelpWindowPriv *priv;
 	GtkWidget      *menu_item;
@@ -423,9 +454,9 @@ yw_toggle_history_back (YelpHistory *history,
 }
 
 static void
-yw_toggle_history_forward (YelpHistory *history,
-			   gboolean     sensitive,
-			   YelpWindow  *window)
+window_toggle_history_forward (YelpHistory *history,
+			       gboolean     sensitive,
+			       YelpWindow  *window)
 {
 	YelpWindowPriv *priv;
 	GtkWidget      *menu_item;
@@ -443,7 +474,7 @@ yw_toggle_history_forward (YelpHistory *history,
 }
 
 static void
-yw_history_action (YelpWindow *window, YelpHistoryAction action)
+window_history_action (YelpWindow *window, YelpHistoryAction action)
 {
 	YelpWindowPriv *priv;
 	YelpURI        *uri;
@@ -464,30 +495,30 @@ yw_history_action (YelpWindow *window, YelpHistoryAction action)
 	}
 	
 	if (uri) {
-		yw_handle_uri (window, uri);
+		window_handle_uri (window, uri);
 	}
 }
 
 static void
-yw_back_button_clicked (GtkWidget *button, YelpWindow *window)
+window_back_button_clicked (GtkWidget *button, YelpWindow *window)
 {
 	g_return_if_fail (GTK_IS_BUTTON (button));
 	g_return_if_fail (YELP_IS_WINDOW (window));
 
-	yw_history_action (window, YELP_WINDOW_ACTION_BACK);
+	window_history_action (window, YELP_WINDOW_ACTION_BACK);
 }
 
 static void
-yw_forward_button_clicked (GtkWidget *button, YelpWindow *window)
+window_forward_button_clicked (GtkWidget *button, YelpWindow *window)
 {
 	g_return_if_fail (GTK_IS_BUTTON (button));
 	g_return_if_fail (YELP_IS_WINDOW (window));
 
-	yw_history_action (window, YELP_WINDOW_ACTION_FORWARD);
+	window_history_action (window, YELP_WINDOW_ACTION_FORWARD);
 }
 
 static void
-yw_home_button_clicked (GtkWidget *button, YelpWindow *window)
+window_home_button_clicked (GtkWidget *button, YelpWindow *window)
 {
 	YelpURI *uri;
 	
@@ -496,7 +527,7 @@ yw_home_button_clicked (GtkWidget *button, YelpWindow *window)
 	uri = yelp_uri_new ("toc:");
 
 	yelp_history_goto (window->priv->history, uri);
-	yelp_view_toc_open_uri (YELP_VIEW_TOC (window->priv->toc_view), uri);
+	yelp_view_toc_open_uri (window->priv->toc_view, uri);
 
 	yelp_uri_unref (uri);
 
@@ -505,7 +536,7 @@ yw_home_button_clicked (GtkWidget *button, YelpWindow *window)
 }
 
 static void
-yw_index_button_clicked (GtkWidget *button, YelpWindow *window)
+window_index_button_clicked (GtkWidget *button, YelpWindow *window)
 {
 	YelpURI *uri;
 	
@@ -520,7 +551,7 @@ yw_index_button_clicked (GtkWidget *button, YelpWindow *window)
 }
 
 static void
-yw_new_window_cb (gpointer data, guint section, GtkWidget *widget)
+window_new_window_cb (gpointer data, guint section, GtkWidget *widget)
 {
 	g_return_if_fail (YELP_IS_WINDOW (data));
 
@@ -528,33 +559,33 @@ yw_new_window_cb (gpointer data, guint section, GtkWidget *widget)
 }
 
 static void
-yw_close_window_cb (gpointer   data,
-		    guint      section,
-		    GtkWidget *widget)
+window_close_window_cb (gpointer   data,
+			guint      section,
+			GtkWidget *widget)
 {
 	gtk_widget_destroy (GTK_WIDGET (data));
 }
 
 static void
-yw_history_go_cb (gpointer data, guint section, GtkWidget *widget)
+window_history_go_cb (gpointer data, guint section, GtkWidget *widget)
 {
-	yw_history_action (data, section);
+	window_history_action (data, section);
 }
 
 static void
-yw_go_home_cb (gpointer data, guint section, GtkWidget *widget)
+window_go_home_cb (gpointer data, guint section, GtkWidget *widget)
 {
-	yw_home_button_clicked (NULL, YELP_WINDOW (data));
+	window_home_button_clicked (NULL, YELP_WINDOW (data));
 }
 
 static void
-yw_go_index_cb (gpointer data, guint section, GtkWidget *widget)
+window_go_index_cb (gpointer data, guint section, GtkWidget *widget)
 {
-	yw_index_button_clicked (NULL, YELP_WINDOW (data));
+	window_index_button_clicked (NULL, YELP_WINDOW (data));
 }
 
 static void
-yw_about_cb (gpointer data, guint section, GtkWidget *widget)
+window_about_cb (gpointer data, guint section, GtkWidget *widget)
 {
 	GtkWidget   *about;
 	const gchar *authors[] = { 
@@ -567,18 +598,19 @@ yw_about_cb (gpointer data, guint section, GtkWidget *widget)
 	gchar       *translator_credits = _("translator_credits");
 	
 	about = gnome_about_new (PACKAGE, VERSION,
-				 "(C) 2001-2002 Mikael Hallendal <micke@codefactory.se>",
+				 "Copyright 2001-2002 Mikael Hallendal <micke@codefactory.se>",
 				 _("Help Browser for GNOME 2.0"),
 				 authors,
 				 NULL,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-				 NULL);
+				 window_load_icon ());
 
+	gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (data));
 	gtk_widget_show (about);
 }
 
 static GtkWidget *
-yw_create_toolbar (YelpWindow *window)
+window_create_toolbar (YelpWindow *window)
 {
 	YelpWindowPriv  *priv;
 	GtkWidget       *toolbar;
@@ -609,11 +641,11 @@ yw_create_toolbar (YelpWindow *window)
 
 	gconf_client_notify_add (conf_client, 
 				 "/desktop/gnome/interface/toolbar_style",
-				 yw_toolbar_style_changed_cb,
+				 window_toolbar_style_changed_cb,
 				 toolbar, NULL, NULL);
 	
 /* 	g_signal_connect(toolbar, "destroy", */
-/* 			 G_CALLBACK(yw_remove_notify_cb), */
+/* 			 G_CALLBACK(window_remove_notify_cb), */
 /* 			 GINT_TO_POINTER(notify_id)); */
 
 	gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), style);
@@ -625,7 +657,7 @@ yw_create_toolbar (YelpWindow *window)
 						     _("Back"),
 						     _("Show previous page in history"),
 						     NULL, icon, 
-						     G_CALLBACK (yw_back_button_clicked),
+						     G_CALLBACK (window_back_button_clicked),
 						     window);
 	
 	gtk_widget_set_sensitive (priv->back_button, FALSE);
@@ -637,7 +669,7 @@ yw_create_toolbar (YelpWindow *window)
 							_("Forward"),
 							_("Show next page in history"),
 							NULL, icon,
-							G_CALLBACK (yw_forward_button_clicked),
+							G_CALLBACK (window_forward_button_clicked),
 							window);
 
 	gtk_widget_set_sensitive (priv->forward_button, FALSE);
@@ -651,7 +683,7 @@ yw_create_toolbar (YelpWindow *window)
 					  _("Home"),
 					  _("Go to home view"), 
 					  NULL, icon,
-					  G_CALLBACK (yw_home_button_clicked),
+					  G_CALLBACK (window_home_button_clicked),
 					  window);
 
 	if (priv->index) {
@@ -662,7 +694,7 @@ yw_create_toolbar (YelpWindow *window)
 						  _("Index"),
 						  _("Search in the index"), 
 						  NULL, icon,
-						  G_CALLBACK (yw_index_button_clicked),
+						  G_CALLBACK (window_index_button_clicked),
 						  window);
 		
 	}
@@ -670,11 +702,35 @@ yw_create_toolbar (YelpWindow *window)
 	return toolbar;
 }
 
+static GdkPixbuf *
+window_load_icon (void)
+{
+	static GdkPixbuf *pixbuf = NULL;
+	
+	if (!pixbuf) {
+		gchar *file;
+		
+		file = gnome_program_locate_file (NULL,
+						  GNOME_FILE_DOMAIN_PIXMAP,
+						  "gnome-help.png",
+						  TRUE,
+						  NULL);
+
+		if (file) {
+			pixbuf = gdk_pixbuf_new_from_file (file,
+							   NULL);
+			g_free (file);
+		}
+	}
+
+	return pixbuf;
+}
+
 static void
-yw_toolbar_style_changed_cb (GConfClient *client,
-			     guint        cnxn_id,
-			     GConfEntry  *entry,
-			     gpointer     data)
+window_toolbar_style_changed_cb (GConfClient *client,
+				 guint        cnxn_id,
+				 GConfEntry  *entry,
+				 gpointer     data)
 {
         GtkToolbarStyle  style   = GTK_TOOLBAR_BOTH;
         GtkToolbar      *toolbar = GTK_TOOLBAR(data);
@@ -694,20 +750,6 @@ yw_toolbar_style_changed_cb (GConfClient *client,
         gtk_toolbar_set_style(toolbar, style);
 }
 
-#if 0
-static void
-yw_remove_notify_cb (GtkObject *obj, gpointer data)
-{
-        GConfClient *conf_client;
-        guint        notify_id;
-
-        conf_client = gconf_client_get_default ();
-        notify_id   = GPOINTER_TO_INT(data);
-
-        gconf_client_notify_remove(conf_client, notify_id);
-}
-#endif 
-
 GtkWidget *
 yelp_window_new (GNode *doc_tree, GList *index)
 {
@@ -727,18 +769,29 @@ yelp_window_new (GNode *doc_tree, GList *index)
 		priv->index_view = yelp_view_index_new (index);
 
 		g_signal_connect (priv->index_view, "uri_selected",
-				  G_CALLBACK (yw_uri_selected_cb),
+				  G_CALLBACK (window_uri_selected_cb),
 				  window);
 	} 
 
 	g_signal_connect (priv->toc_view, "uri_selected",
-			  G_CALLBACK (yw_uri_selected_cb),
-			  window);
-	g_signal_connect (priv->content_view, "uri_selected",
-			  G_CALLBACK (yw_uri_selected_cb),
+			  G_CALLBACK (window_uri_selected_cb),
 			  window);
 
-	yw_populate (window);
+	g_signal_connect (priv->toc_view, "title_changed",
+			  G_CALLBACK (window_title_changed_cb),
+			  window);
+
+	g_signal_connect (priv->content_view, "uri_selected",
+			  G_CALLBACK (window_uri_selected_cb),
+			  window);
+
+	g_signal_connect (priv->content_view, "title_changed",
+			  G_CALLBACK (window_title_changed_cb),
+			  window);
+
+	window_populate (window);
+
+	gtk_window_set_icon (GTK_WINDOW (window), window_load_icon ());
 
         return GTK_WIDGET (window);
 }
@@ -756,9 +809,9 @@ yelp_window_open_uri (YelpWindow  *window,
 
 	uri = yelp_uri_new (str_uri);
 
-	if (yelp_uri_exists (uri)) {
-		yw_handle_uri (window, uri);
-	}
+	yelp_history_goto (priv->history, uri);
+	
+	window_handle_uri (window, uri);
 	
 	yelp_uri_unref (uri);
 }
